StorageClient class abstract

Абстрактная реализации клиента для Provider реализаций

Constructors

StorageClient()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getBool(String key) bool?
getDouble(String key) double?
getInt(String key) int?
getString(String key) String?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key) → void
setBool(String key, bool value) → void
setDouble(String key, double value) → void
setInt(String key, int value) → void
setString(String key, String value) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited